@@ -22,7 +22,19 @@ test_that("minimal", {
   testthat::skip_if(!R6::is.R6(repo))
 
   expect_message(
-    checkDependencies(repo),
+    suppressWarnings(checkDependencies(repo = repo)),
+    "All dependencies are approved."
+  )
+  unlink(repo$getPath(), recursive = TRUE)
+})
+
+
+test_that("parallel", {
+  repo <- makeRepo()
+  testthat::skip_if(!R6::is.R6(repo))
+
+  expect_message(
+    suppressWarnings(checkDependencies(repo = repo, nThreads = 2)),
     "All dependencies are approved."
   )
   unlink(repo$getPath(), recursive = TRUE)
